@@ -50,7 +50,7 @@ def save_config(node, force=False):
         files_to_create.append(filepath)
     for node_file in files_to_create:
         with open(node_file, 'w') as f:
-            f.write(json.dumps(node, indent=4))
+            f.write(json.dumps(node, indent=4, sort_keys=True))
     return tmp_filename
 
 
@@ -61,7 +61,7 @@ def _get_ipaddress(node):
     """
     if "ipaddress" not in node:
         with settings(hide('stdout'), warn_only=True):
-            output = sudo('ohai ipaddress')
+            output = sudo('ohai -l warn ipaddress')
         if output.succeeded:
             try:
                 node['ipaddress'] = json.loads(output)[0]
@@ -335,8 +335,8 @@ def _add_search_patch():
 
     """
     # Create extra cookbook dir
-    lib_path = os.path.join(
-        env.node_work_path, cookbook_paths[0], 'chef_solo_search_lib', 'libraries')
+    lib_path = os.path.join(env.node_work_path, cookbook_paths[0],
+                            'chef_solo_search_lib', 'libraries')
     with hide('running', 'stdout'):
         sudo('mkdir -p {0}'.format(lib_path))
     # Add search and environment patch to the node's cookbooks
